# banal

Commons of Python micro-functions. This basically an out-sourced, shared
utils module.

Rules:

* Must work in Python 2 and Python 3
* Cannot depend on anything but six and the standard library
